[asterisk-commits] branch group/autoconf_and_menuselect r10765 - in /team/group/autoconf_and_men...

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Wed Feb 22 12:50:25 MST 2006


Author: russell
Date: Wed Feb 22 13:50:19 2006
New Revision: 10765

URL: http://svn.digium.com/view/asterisk?rev=10765&view=rev
Log:
update menuselect and apps, utils, and cdr to work with current Makefiles

Modified:
    team/group/autoconf_and_menuselect/apps/Makefile
    team/group/autoconf_and_menuselect/apps/makeopts.xml
    team/group/autoconf_and_menuselect/build_tools/menuselect.c
    team/group/autoconf_and_menuselect/cdr/Makefile
    team/group/autoconf_and_menuselect/cdr/makeopts.xml
    team/group/autoconf_and_menuselect/include/asterisk/linkedlists.h
    team/group/autoconf_and_menuselect/utils/Makefile
    team/group/autoconf_and_menuselect/utils/makeopts.xml

Modified: team/group/autoconf_and_menuselect/apps/Makefile
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/apps/Makefile?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/apps/Makefile (original)
+++ team/group/autoconf_and_menuselect/apps/Makefile Wed Feb 22 13:50:19 2006
@@ -13,24 +13,7 @@
 
 MODS:=$(patsubst %.c,%.so,$(wildcard app_*.c))
 
-#
-# Experimental things
-#
-MODS:=$(filter-out app_ivrdemo.so,$(MODS))
-MODS:=$(filter-out app_skel.so,$(MODS))
-MODS:=$(filter-out app_rpt.so,$(MODS))
-
-ifndef WITHOUT_ZAPTEL
-ZAPAVAIL:=$(wildcard $(CROSS_COMPILE_TARGET)/usr/include/linux/zaptel.h $(CROSS_COMPILE_TARGET)/usr/local/include/zaptel.h)
-endif
-
-ifeq (${ZAPAVAIL},)
-  MODS:=$(filter-out app_zapras.so app_meetme.so app_flash.so app_zapbarge.so app_zapscan.so app_page.so,$(MODS))
-endif
-
-ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/local/include/osp/osp.h $(CROSS_COMPILE_TARGET)/usr/include/osp/osp.h),)
-  MODS:=$(filter-out app_osplookup.so,$(MODS))
-endif
+MODS:=$(filter-out $(MENUSELECT_APPS),$(MODS))
 
 ifneq ($(shell if [[ 0x`$(CROSS_COMPILE_BIN)curl-config --vernum` -ge 0x70907 ]]; then echo "OK" ; fi),)
   CURLLIBS:=$(shell $(CROSS_COMPILE_BIN)curl-config --libs)

Modified: team/group/autoconf_and_menuselect/apps/makeopts.xml
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/apps/makeopts.xml?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/apps/makeopts.xml (original)
+++ team/group/autoconf_and_menuselect/apps/makeopts.xml Wed Feb 22 13:50:19 2006
@@ -1,7 +1,7 @@
 <?xml version="1.0"?>
 
 <category>
-	<name>APPS</name>
+	<name>MENUSELECT_APPS</name>
 	<displayname>Applications</displayname>
 	<description>Diaplan Applications</description>
 	<member>
@@ -24,6 +24,10 @@
 	</member>
 	<member>
 		<name>app_controlplayback.so</name>
+	</member>
+	<member>
+		<name>app_curl.so</name>
+		<depend>curl</depend>
 	</member>
 	<member>
 		<name>app_db.so</name>
@@ -147,6 +151,7 @@
 	</member>
 	<member>
 		<name>app_rpt.so</name>
+		<depend>zaptel</depend>
 	</member>
 	<member>
 		<name>app_sayunixtime.so</name>

Modified: team/group/autoconf_and_menuselect/build_tools/menuselect.c
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/build_tools/menuselect.c?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/cdr/Makefile (original)
+++ team/group/autoconf_and_menuselect/cdr/Makefile Wed Feb 22 13:50:19 2006
@@ -13,20 +13,9 @@
 
 MODS:=$(patsubst %.c,%.so,$(wildcard cdr_*.c))
 
-ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/odbcinst.h $(CROSS_COMPILE_TARGET)/usr/local/include/odbcinst.h),)
-  MODS:=$(filter-out cdr_odbc.so,$(MODS))
-endif
+MODS:=$(filter-out $(MENUSELECT_CDR),$(MODS))
 
-ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/postgresql $(CROSS_COMPILE_TARGET)/usr/local/pgsql/include $(CROSS_COMPILE_TARGET)/usr/include/pgsql $(CROSS_COMPILE_TARGET)/usr/local/include/pgsql $(CROSS_COMPILE_TARGET)/opt/pgsql/include $(CROSS_COMPILE_TARGET)/usr/include/libpq-fe.h),)
-  MODS:=$(filter-out cdr_pgsql.so,$(MODS))
-endif
-
-ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/sqlite.h),)
-  MODS:=$(filter-out cdr_sqlite.so,$(MODS))
-endif
-
-ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/tds.h $(CROSS_COMPILE_TARGET)/usr/local/include/tds.h $(CROSS_COMPILE_TARGET)/usr/include/freetds/tds.h),)
-  MODS:=$(filter-out cdr_tds.so,$(MODS))
+ifeq ($(findstring cdr_tds.so,$(MODS)),)
   NOTDS=1
 endif
 

Modified: team/group/autoconf_and_menuselect/cdr/makeopts.xml
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/cdr/makeopts.xml?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/cdr/makeopts.xml (original)
+++ team/group/autoconf_and_menuselect/cdr/makeopts.xml Wed Feb 22 13:50:19 2006
@@ -1,7 +1,7 @@
 <?xml version="1.0"?>
 
 <category>
-	<name>CDR_MODULES</name>
+	<name>MENUSELECT_CDR</name>
 	<displayname>CDR Storage</displayname>
 	<member>
 		<name>cdr_csv.so</name>

Modified: team/group/autoconf_and_menuselect/include/asterisk/linkedlists.h
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/include/asterisk/linkedlists.h?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/include/asterisk/linkedlists.h (original)
+++ team/group/autoconf_and_menuselect/include/asterisk/linkedlists.h Wed Feb 22 13:50:19 2006
@@ -29,6 +29,8 @@
   \brief A set of macros to manage forward-linked lists.
 */
 
+#ifndef AST_LIST_NOLOCK
+
 /*!
   \brief Attempts to lock a list.
   \param head This is a pointer to the list head structure

Modified: team/group/autoconf_and_menuselect/utils/Makefile
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/utils/Makefile?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/utils/Makefile (original)
+++ team/group/autoconf_and_menuselect/utils/Makefile Wed Feb 22 13:50:19 2006
@@ -16,15 +16,19 @@
 #
 CFLAGS+=-DNO_AST_MM
 
+TARGET=astman smsq stereorize streamplayer
+
+TARGET:=$(filter-out $(MENUSELECT_UTILS),$(TARGET))
+
 ifeq (${OSARCH},SunOS)
   SOL=../strcompat.o
   SOLLIBS=-lsocket -lnsl
 endif
 
-all: depend $(UTILS)
+all: depend $(TARGET)
 
 install:
-	for x in $(UTILS); do \
+	for x in $(TARGET); do \
 		if [ "$$x" != "none" ]; then \
 			$(INSTALL) -m 755 $$x $(DESTDIR)$(ASTSBINDIR)/$$x; \
 		fi; \

Modified: team/group/autoconf_and_menuselect/utils/makeopts.xml
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/utils/makeopts.xml?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================
--- team/group/autoconf_and_menuselect/utils/makeopts.xml (original)
+++ team/group/autoconf_and_menuselect/utils/makeopts.xml Wed Feb 22 13:50:19 2006
@@ -1,7 +1,7 @@
 <?xml version="1.0"?>
 
 <category>
-	<name>UTILS</name>
+	<name>MENUSELECT_UTILS</name>
 	<displayname>Utilities</displayname>
 	<member>
 		<name>astman</name>



More information about the asterisk-commits mailing list
--- team/group/autoconf_and_menuselect/build_tools/menuselect.c (original)
+++ team/group/autoconf_and_menuselect/build_tools/menuselect.c Wed Feb 22 13:50:19 2006
@@ -271,6 +271,9 @@
 
 			if (!(mem = my_calloc(1, sizeof(*mem))))
 				return -1;
+			
+			/* Enabled by default */
+			mem->enabled = 1;
 
 			mem->name = cur3->child->value.opaque;
 			if ((cur3 = mxmlFindElement(cur2, cur2, "description", NULL, NULL, MXML_DESCEND)) && cur3->child)
@@ -331,8 +334,11 @@
 				}
 				break; /* This depencency is not met, no need to keep checking */
 			}
-		}
-	}
+			if (mem->depsfailed)
+				mem->enabled = 0;
+		}
+	}
+
 
 	/* We save all of the other trees because we use them later.  We don't need this tree anymore. */
 	mxmlDelete(root);
@@ -358,8 +364,8 @@
 	return res;
 }
 
-/*! \brief Given the string representation of a member and category, find it and mark it as enabled */
-void mark_as_enabled(const char *member, const char *category)
+/*! \brief Given the string representation of a member and category, find it and mark it as disabled */
+void mark_as_disabled(const char *member, const char *category)
 {
 	struct category *cat;
 	struct member *mem;
@@ -369,8 +375,7 @@
 			continue;
 		AST_LIST_TRAVERSE(&cat->members, mem, list) {
 			if (!strcmp(member, mem->name)) {
-				if (!mem->depsfailed)
-					mem->enabled = 1;
+				mem->enabled = 0;
 				break;
 			}
 		}
@@ -380,7 +385,7 @@
 	}
 
 	if (!cat)
-		fprintf(stderr, "category '%s' not found! Can't mark '%s' as enabled.\n", category, member);
+		fprintf(stderr, "category '%s' not found! Can't mark '%s' as disabled.\n", category, member);
 }
 
 /*! \brief Toggle a member of a category at the specified index to enabled/disabled */
@@ -438,7 +443,7 @@
 			if (strlen_zero(member))
 				continue;
 
-			mark_as_enabled(member, category);
+			mark_as_disabled(member, category);
 		}
 	}
 
@@ -461,7 +466,7 @@
 	AST_LIST_TRAVERSE(&categories, cat, list) {
 		fprintf(f, "%s=", cat->name);
 		AST_LIST_TRAVERSE(&cat->members, mem, list) {
-			if (mem->enabled)
+			if (!mem->enabled || mem->depsfailed) /* We're listing everything *not* to build */
 				fprintf(f, "%s ", mem->name);
 		}
 		fprintf(f, "\n");

Modified: team/group/autoconf_and_menuselect/cdr/Makefile
URL: http://svn.digium.com/view/asterisk/team/group/autoconf_and_menuselect/cdr/Makefile?rev=10765&r1=10764&r2=10765&view=diff
==============================================================================